package
Version:
v0.0.0-...-80b40fb
Opens a new window with list of versions in this module.
Published: Apr 5, 2024
License: Unlicense
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func LogBlue(message string, args ...interface{})
func LogDarkYellow(message string, args ...interface{})
func LogGreen(message string, args ...interface{})
func LogRed(message string, args ...interface{})
Source Files
¶
Click to show internal directories.
Click to hide internal directories.